package com.cenqua.fisheye.user.plugin;

import java.io.Serializable;

/**
 * A token representing a successful login.
 *
 * <p>
 * Instances of this class are stored in a Servlet session, and are long-lived.
 * An instance may live longer than the {@link FishEyeAuthenticator} that created it.
 * It should not (for example) contain connections to a database, etc.
 * </p>
 */
public interface AuthToken extends Serializable {
    /**
     * The username used when authenticating the user
     */
    public abstract String getUsername();
    /**
     * The email address of the user (if the underlying authenticator can automatically
     * determine it).
     * @return user's email address, or null if not known.
     */
    public abstract String getEmail();

    /**
     * The full name to use when displaying data by this user.
     *
     * @return the name to use for display purposes, or <code>null</code>.
     */
    String getDisplayName();
}
